==> tuia-advert-center-api-1.5.0-20180623.044342-23-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/account/AdvertiserDataSnapshotCountDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.account;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年11月16日 17:27
 * @descript:
 * @version: 1.0
 */
public class AdvertiserDataSnapshotCountDto {

    /**
     * 存入
     */
    private Long balanceIn;

    /**
     * 支出
     */
    private Long balanceOut;

    /**
     * 存入 --- 充值
     */
    private Long balanceInRecharge;

    /**
     * 存入 --- 其它
     */
    private Long balanceInOther;

    /**
     * 支出 --- 消耗
     */
    private Long balanceOutConsume;

    /**
     * 支出 --- 其它
     */
    private Long balanceOutOther;

    /**
     * 期初总余额
     */
    private Long beginTotal;

    /**
     * 期末总余额
     */
    private Long endTotal;

    public Long getBalanceIn() {
        return balanceIn;
    }

    public void setBalanceIn(Long balanceIn) {
        this.balanceIn = balanceIn;
    }

    public Long getBalanceOut() {
        return balanceOut;
    }

    public void setBalanceOut(Long balanceOut) {
        this.balanceOut = balanceOut;
    }

    public Long getBalanceInRecharge() {
        return balanceInRecharge;
    }

    public void setBalanceInRecharge(Long balanceInRecharge) {
        this.balanceInRecharge = balanceInRecharge;
    }

    public Long getBalanceInOther() {
        return balanceInOther;
    }

    public void setBalanceInOther(Long balanceInOther) {
        this.balanceInOther = balanceInOther;
    }

    public Long getBalanceOutConsume() {
        return balanceOutConsume;
    }

    public void setBalanceOutConsume(Long balanceOutConsume) {
        this.balanceOutConsume = balanceOutConsume;
    }

    public Long getBalanceOutOther() {
        return balanceOutOther;
    }

    public void setBalanceOutOther(Long balanceOutOther) {
        this.balanceOutOther = balanceOutOther;
    }

    public Long getBeginTotal() {
        return beginTotal;
    }

    public void setBeginTotal(Long beginTotal) {
        this.beginTotal = beginTotal;
    }

    public Long getEndTotal() {
        return endTotal;
    }

    public void setEndTotal(Long endTotal) {
        this.endTotal = endTotal;
    }
}

==> tuia-advert-center-api-2.2.74-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/account/AdvertiserDataSnapshotCountDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.account;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年11月16日 17:27
 * @descript:
 * @version: 1.0
 */
public class AdvertiserDataSnapshotCountDto  implements Serializable {

    private static final long serialVersionUID = -7306200714107563997L;
    /**
     * 存入
     */
    private Long balanceIn;

    /**
     * 支出
     */
    private Long balanceOut;

    /**
     * 存入 --- 充值
     */
    private Long balanceInRecharge;

    /**
     * 存入 --- 其它
     */
    private Long balanceInOther;

    /**
     * 支出 --- 消耗
     */
    private Long balanceOutConsume;

    /**
     * 支出 --- 其它
     */
    private Long balanceOutOther;

    /**
     * 期初总余额
     */
    private Long beginTotal;

    /**
     * 期末总余额
     */
    private Long endTotal;

    public Long getBalanceIn() {
        return balanceIn;
    }

    public void setBalanceIn(Long balanceIn) {
        this.balanceIn = balanceIn;
    }

    public Long getBalanceOut() {
        return balanceOut;
    }

    public void setBalanceOut(Long balanceOut) {
        this.balanceOut = balanceOut;
    }

    public Long getBalanceInRecharge() {
        return balanceInRecharge;
    }

    public void setBalanceInRecharge(Long balanceInRecharge) {
        this.balanceInRecharge = balanceInRecharge;
    }

    public Long getBalanceInOther() {
        return balanceInOther;
    }

    public void setBalanceInOther(Long balanceInOther) {
        this.balanceInOther = balanceInOther;
    }

    public Long getBalanceOutConsume() {
        return balanceOutConsume;
    }

    public void setBalanceOutConsume(Long balanceOutConsume) {
        this.balanceOutConsume = balanceOutConsume;
    }

    public Long getBalanceOutOther() {
        return balanceOutOther;
    }

    public void setBalanceOutOther(Long balanceOutOther) {
        this.balanceOutOther = balanceOutOther;
    }

    public Long getBeginTotal() {
        return beginTotal;
    }

    public void setBeginTotal(Long beginTotal) {
        this.beginTotal = beginTotal;
    }

    public Long getEndTotal() {
        return endTotal;
    }

    public void setEndTotal(Long endTotal) {
        this.endTotal = endTotal;
    }
}
